oceanum.datamesh.Datasource — oceanum 0.7.2 documentation

# oceanum.datamesh.Datasource

pydantic model oceanum.datamesh.Datasource

  Datasource

  Fields

    - `coordinates (Dict[oceanum.datamesh.datasource.Coordinates, str])`

    - `dataschema (Optional[oceanum.datamesh.datasource.Schema])`

    - `description (Optional[str])`

    - `details (Optional[pydantic.networks.AnyHttpUrl])`

    - `driver (str)`

    - `driver_args (Optional[dict])`

    - `geom (oceanum.datamesh.datasource.Geometry)`

    - `id (str)`

    - `info (Optional[dict])`

    - `last_modified (Optional[datetime.datetime])`

    - `name (str)`

    - `parameters (Optional[dict])`

    - `parchive (Optional[oceanum.datamesh.datasource.Timeperiod])`

    - `tags (Optional[list])`

    - `tend (Optional[datetime.datetime])`

    - `tstart (Optional[datetime.datetime])`

  field coordinates: Dict[Coordinates, str] [Required]
    Coordinates in datasource, referenced by standard coordinate keys. The dictionary keys map to coordinates variables in the datasource.

      Ensemble: “e” Rasterband: “b” Category: “c” Quantile: “q” Season: “s” Month: “m” Time: “t” Vertical: “z” Northing: “y” Easting: “x” Station: “s” (Locations assumed stationary, datasource with a multigeometry indexed by station coordinate) Geometry: “g” (Abstract coordinate - a 2 or 3D geometry that defines a feature location) Frequency: “f” Direction:”d”

    Example {“t”:”time”,”x”:”longitude”,”y”:”latitude”}

  field dataschema: Optional[Schema] = Schema(attrs={}, dims={}, coords={}, data_vars={}) (alias 'schema')

    Datasource schema

  field description: Optional[str] = ''

    Description of datasource

    Constraints

      - maxLength = 1500

  field details: Optional[AnyHttpUrl] = None

    URL to further details about the datasource

    Constraints

      - minLength = 1

      - maxLength = 65536

      - format = uri

  field driver: str [Required]
  field driver_args: Optional[dict] = None (alias 'args')

    Driver arguments for datasource. These are driver dependent.

  field geom: Geometry [Required]

    Valid shapely or geoJSON geometry describing the spatial extent of the datasource

  field id: str [Required]

    Unique ID for the datasource

    Constraints

      - maxLength = 80

      - minLength = 3

      - pattern = ^[a-z0-9-_]+$

  field info: Optional[dict] = ''

    Additional datasource descriptive metadata

  field last_modified: Optional[datetime] = datetime.datetime(2023, 1, 10, 19, 39, 50, 742000)

    Last time datasource was modified

  field name: str [Required]

    Human readable name for the datasource

    Constraints

      - maxLength = 64

  field parameters: Optional[dict] = {}

    Additional parameters for accessing datasource

  field parchive: Optional[Timeperiod] = None

    Duration of a rolling archive (time before present). Must be a valid ISO8601 interval string or None.

  field tags: Optional[list] = []

    Metadata keyword tags related to the datasource

  field tend: Optional[datetime] = None

    Latest time in datasource. Must be a valid ISO8601 datetime string

  field tstart: Optional[datetime] = None

    Earliest time in datasource. Must be a valid ISO8601 datetime string

  property attributes

    Datasource global attributes. Note that these are None (undefined) for a summary dataset.

  property bounds

    Bounding box of datasource geographical extent

    Type

      list[float]

  property geometry
  property variables

    Datasource variables (or properties). Note that these are None (undefined) for a summary dataset.